@@ -1,9 +1,9 @@
 # -*-cperl-*-
 #
 # Crypt::Unsnoopable - Completely unsnoopable messaging
-# Copyright (c) 2017 Ashish Gulhati <crypt-unsnoopable at hash.neo.tc>
+# Copyright (c) Ashish Gulhati <crypt-unsnoopable at hash.neo.tc>
 #
-# $Id: lib/Crypt/Unsnoopable.pm v1.008 Sun Dec 10 01:36:27 PST 2017 $
+# $Id: lib/Crypt/Unsnoopable.pm v1.009 Tue Oct 16 20:45:55 PDT 2018 $
 
 package Crypt::Unsnoopable;
 
@@ -19,7 +19,7 @@ use vars qw( $VERSION $AUTOLOAD @ISA @EXPORT_OK );
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(dec heX);
 
-our ( $VERSION ) = '$Revision: 1.008 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.009 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my ($class, %arg) = @_;
@@ -127,8 +127,8 @@ Crypt::Unsnoopable - Completely unsnoopable messaging
 
 =head1 VERSION
 
- $Revision: 1.008 $
- $Date: Sun Dec 10 01:36:27 PST 2017 $
+ $Revision: 1.009 $
+ $Date: Tue Oct 16 20:45:55 PDT 2018 $
 
 =head1 SYNOPSIS
 
@@ -234,10 +234,12 @@ L<http://search.cpan.org/dist/Crypt-Unsnoopable/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2001-2017 Ashish Gulhati.
+Copyright (c) Ashish Gulhati.
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of the Artistic License 2.0.
+This software package is Open Software; you can use, redistribute,
+and/or modify it under the terms of the Open Artistic License 2.0.
 
-See http://www.perlfoundation.org/artistic_license_2_0 for the full
-license terms.
+Please see L<http://www.opensoftwr.org/oal20.txt> for the full license
+terms, and ensure that the license grant applies to you before using
+or modifying this software. By using or modifying this software, you
+indicate your agreement with the license terms.
